CleanResults class

Constructors

CleanResults({required int projectsFound, required int projectsCleaned, required int spaceFreed})

Properties

hashCode → int
The hash code for this object.
no setterinherited
projectsCleaned → int
final
projectsFound → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
spaceFreed → int
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited